Method: AppControllerClient#get_role_info

Defined in:
lib/app_controller_client.rb

#get_role_infoObject

Asks the AppController to see what roles each node is running in AppScale. The result is an Array, where each item is a Hash that contains information about the given node.



174
175
176
177
178
# File 'lib/app_controller_client.rb', line 174

def get_role_info()
  make_call(NO_TIMEOUT, ABORT_ON_FAIL) { 
    @conn.get_role_info(@secret) 
  }
end